from ..utils import packages_are_installed
import logging
if not packages_are_installed(["s3fs", "minio"]): 
    message = "Please install pysparkutilities (https://pypi.org/project/pyspark-utilities/), pyspark and a Java virtual machine if you want to use datasets contained in Hive DB."
    logging.error(message)
    exit(1)

else:
    import glob
    import os
    from pysparkutilities import ds_initializer
    from pysparkutilities.spark_initializer import spark_initializer
    from bdaserviceutils import get_args


    def from_spark_to_pandas_df_using_disk(df, path='/tmp/tmp_csv_df'):

        df = df.to_pandas_on_spark()
        df.to_csv(path, header=True, num_files=1, mode="overwrite")

        extension = 'csv'
        os.chdir(path)
        result = glob.glob('*.{}'.format(extension))[0]

        return result

    def init_spark():
        return spark_initializer("Ds-io", get_args(), additional_config=[('spark.sql.execution.arrow.enabled', True)])


    def get_path(name):
        df = ds_initializer.load_dataset(sc=init_spark(), name=name, read_all=False)
        return from_spark_to_pandas_df_using_disk(df)




from ..utils import packages_are_installed
import logging

if not packages_are_installed(["s3fs", "minio"]): 
    message = "Please install minio (https://pypi.org/project/minio/) and s3fs (https://pypi.org/project/s3fs/) if you want to use datasets contained in Minio."
    logging.error(message)
    exit(1)
else:

    from ..utils import input_or_output, get_asset_property


    def get_path(name):
        
        bucket_name = get_asset_property(asset_name=name, property="minio_bucket")

        if input_or_output(name) == "input":
            return "s3://" + bucket_name + "/" + get_asset_property(name)
        elif input_or_output(name) == "output":
            return "s3://" + bucket_name + "/" + get_asset_property(name)
        else:
            raise Exception("Error: cannot establish if dataset is an input or output one! Are you sure the name is right?")

    def get_metadata(name):

        use_ssl = get_asset_property(asset_name=name, property="use_ssl") if get_asset_property(asset_name=name, property="use_ssl") is not None else False
        if use_ssl:
            raise Exception("Error: ssl for object storage non implemented")

        # Get credentials
        minio_url = get_asset_property(asset_name=name, property="minIO_URL")
        access_key = get_asset_property(asset_name=name, property="minIO_ACCESS_KEY")
        secret_key = get_asset_property(asset_name=name, property="minIO_SECRET_KEY")
        bucket_name = get_asset_property(asset_name=name, property="minio_bucket")

        metadata = {"type": "minio", 
                    "url": minio_url,
                    "access_key": access_key,
                    "secret_key": secret_key,
                    "bucket_name": bucket_name,
                    "use_ssl": use_ssl}

        return metadata